package org.apache.commons.lang3.exception;

package .var.folders.cl.9twcgjfx4vsg5zl73c6wxmvm0000gn.T;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.lang3.exception.ExceptionContext;
import org.apache.commons.lang3.exception.ExceptionUtils;
import org.apache.commons.lang3.tuple.ImmutablePair;
import org.apache.commons.lang3.tuple.Pair;

public class DefaultExceptionContext implements ExceptionContext, Serializable {
  private static final long serialVersionUID = 20110706L;
  
  private final List<Pair<String, Object>> contextValues = new ArrayList<>();
  
  public org.apache.commons.lang3.exception.DefaultExceptionContext addContextValue(String label, Object value) {
    this.contextValues.add(new ImmutablePair<>(label, value));
    return this;
  }
  
  public org.apache.commons.lang3.exception.DefaultExceptionContext setContextValue(String label, Object value) {
    this.contextValues.removeIf(p -> StringUtils.equals(label, (CharSequence)p.getKey()));
    addContextValue(label, value);
    return this;
  }
  
  public List<Object> getContextValues(String label) {
    List<Object> values = new ArrayList();
    for (Pair<String, Object> pair : this.contextValues) {
      if (StringUtils.equals(label, pair.getKey()))
        values.add(pair.getValue()); 
    } 
    return values;
  }
  
  public Object getFirstContextValue(String label) {
    for (Pair<String, Object> pair : this.contextValues) {
      if (StringUtils.equals(label, pair.getKey()))
        return pair.getValue(); 
    } 
    return null;
  }
  
  public Set<String> getContextLabels() {
    Set<String> labels = new HashSet<>();
    for (Pair<String, Object> pair : this.contextValues)
      labels.add(pair.getKey()); 
    return labels;
  }
  
  public List<Pair<String, Object>> getContextEntries() {
    return this.contextValues;
  }
  
  public String getFormattedExceptionMessage(String baseMessage) {
    StringBuilder buffer = new StringBuilder(256);
    if (baseMessage != null)
      buffer.append(baseMessage); 
    if (!this.contextValues.isEmpty()) {
      if (buffer.length() > 0)
        buffer.append('\n'); 
      buffer.append("Exception Context:\n");
      int i = 0;
      for (Pair<String, Object> pair : this.contextValues) {
        buffer.append("\t[");
        buffer.append(++i);
        buffer.append(':');
        buffer.append(pair.getKey());
        buffer.append("=");
        Object value = pair.getValue();
        if (value == null) {
          buffer.append("null");
        } else {
          String valueStr;
          try {
            valueStr = value.toString();
          } catch (Exception e) {
            valueStr = "Exception thrown on toString(): " + ExceptionUtils.getStackTrace(e);
          } 
          buffer.append(valueStr);
        } 
        buffer.append("]\n");
      } 
      buffer.append("---------------------------------");
    } 
    return buffer.toString();
  }
}
